@@ -9,8 +9,12 @@ from jdTextEdit.core.BuiltinLanguage import BuiltinLanguage
 from jdTextEdit.core.api.EditorSignals import EditorSignals
 from jdTextEdit.core.api.MainWindowSignals import MainWindowSignals
 from jdTextEdit.core.api.ApplicationSignals import ApplicationSignals
+from jdTextEdit.core.api.TabWidgetSignals import TabWidgetSignals
 from jdTextEdit.core.api.PluginAPI import PluginAPI
 from jdTextEdit.core.DefaultTheme import DefaultTheme
+from jdTextEdit.core.FileTheme import FileTheme
+from jdTextEdit.api.LanguageBase import LanguageBase
+from typing import List
 import argparse
 import chardet
 import shutil
@@ -20,7 +24,7 @@ import os
 
 class Enviroment():
     def __init__(self):
-        self.version = "8.3"
+        self.version = "9.0"
         self.programDir = os.path.dirname(os.path.realpath(__file__))
 
         parser = argparse.ArgumentParser()
@@ -31,6 +35,7 @@ class Enviroment():
         parser.add_argument("--no-session-restore",action="store_true", dest="disableSessionRestore",help="Disable Session Restore")
         parser.add_argument("--disable-updater",action="store_true", dest="disableUpdater",help="Disable the Updater")
         parser.add_argument("--distribution-file",dest="distributionFile",help="Sets custom distribution.json")
+        parser.add_argument("--language",dest="language",help="Starts jdTextEdit in the given language")
         self.args = parser.parse_args().__dict__
 
         #if distributionFile:
@@ -44,6 +49,7 @@ class Enviroment():
             self.dataDir = getDataPath(self)
 
         if not os.path.isdir(self.dataDir):
+            self.firstRun = True
             try:
                 if os.path.isdir(os.path.join(self.programDir,"default_data")):
                     shutil.copytree(os.path.join(self.programDir,"default_data"), self.dataDir)
@@ -52,6 +58,8 @@ class Enviroment():
             except:
                 showMessageBox("Unable to create data folder",f"jdTextEdit is unable to create his data folder {self.dataDir}. Maybe you've installed it in a system directory and try to run it in portable mode")
                 sys.exit(2)
+        else:
+            self.firstRun = False
 
         if not(self.distributionSettings.get("enableUpdater",True)) or self.args["disableUpdater"] or os.getenv("SNAP") or os.getenv("JDTEXTEDIT_DISABLE_UPDATER"):
             self.enableUpdater = False
@@ -62,7 +70,9 @@ class Enviroment():
         if os.path.isfile(os.path.join(self.dataDir,"settings.json")):
             self.settings.load(os.path.join(self.dataDir,"settings.json"))
 
-        if self.settings.language == "default":
+        if self.args["language"]:
+            self.translations = jdTranslationHelper(self.args["language"])
+        elif self.settings.language == "default":
             self.translations = jdTranslationHelper(lang=QLocale.system().name())
         else:
             self.translations = jdTranslationHelper(lang=self.settings.language)
@@ -91,7 +101,7 @@ class Enviroment():
 
         self.lexerList = getLexerList()
 
-        self.languageList = []
+        self.languageList: List[LanguageBase] = []
         for i in self.lexerList:
             lang = BuiltinLanguage(self,i)
             self.languageList.append(lang)
@@ -127,6 +137,9 @@ class Enviroment():
         except ImportError:
             pass
 
+        self.lastSavePath = ""
+        self.lastOpenPath =""
+
         self.documentSavedIcon = QIcon(os.path.join(self.programDir,"icons","document-saved.png"))
         self.documentUnsavedIcon = QIcon(os.path.join(self.programDir,"icons","document-unsaved.png"))
 
@@ -135,6 +148,7 @@ class Enviroment():
         self.editorSignals = EditorSignals()
         self.mainWindowSignals = MainWindowSignals()
         self.applicationSignals = ApplicationSignals()
+        self.tabWidgetSignals = TabWidgetSignals()
         self.customSettingsTabs = []
         self.customBigFilesSettings = []
         self.defaultSettings = []
@@ -142,17 +156,30 @@ class Enviroment():
 
         self.pluginAPI.addTheme(DefaultTheme(self))
 
-        #self.loadThemeDirectory(os.path.join(self.programDir,"themes"))
+        self.loadThemeDirectory(os.path.join(self.programDir,"themes"))
+        self.loadThemeDirectory(os.path.join(self.dataDir, "themes"))
 
-    def translate(self, string):
-        #Just a litle shortcut
-        return self.translations.translate(string)
+    def translate(self, key: str) -> str:
+        """
+        Returns the Translation of the given key.
+        :param key: The Key
+        :return: The Translation
+        """
+        return self.translations.translate(key)
 
     def loadThemeDirectory(self,path):
+        if not os.path.isdir(path):
+            try:
+                os.makedirs(path)
+            except:
+                return
         themeList = os.listdir(path)
         for i in themeList:
-            theme = FileTheme(os.path.join(path,i))
-            self.pluginAPI.addTheme(theme)
+            try:
+                theme = FileTheme(os.path.join(path,i))
+                self.pluginAPI.addTheme(theme)
+            except:
+                pass
 
     def saveRecentFiles(self):
         with open(os.path.join(self.dataDir,"recentfiles.json"), 'w', encoding='utf-8') as f:
