@@ -1,5 +1,7 @@
 from PyQt5.QtGui import QFont, QKeySequence
-from jdTextEdit.Functions import showMessageBox
+from jdTextEdit.Functions import showMessageBox, readJsonFile
+from pathlib import Path
+from typing import Any
 import platform
 import json
 import os
@@ -17,6 +19,7 @@ class Settings():
         self.maxRecentFiles = 10
         self.saveSession = True
         self.loadPlugins = True
+        self.searchUpdates = False
         self.windowFileTitle = True
         self.saveWindowState = True
         self.eolFileEnd = False
@@ -70,12 +73,18 @@ class Settings():
         self.bigFileDisableHighlight = True
         self.bigFileDisableEncodingDetect = True
         self.bigFileShowBanner = True
+        self.saveFilePathType = 0
+        self.saveFileCustomPath = str(Path.home())
+        self.openFilePathType = 0
+        self.openFileCustomPath = str(Path.home())
         self.editorConfigUseIndentStyle = True
         self.editorConfigTabWidth = True
         self.editorConfigEndOfLine = True
         self.editorConfigTrimWhitespace = True
         self.editorConfigInsertNewline = True
         self.editorConfigShowBanner = False
+        self.settingsWindowUseModernDesign = True
+        self.enableUserChrome = True
         self.disabledPlugins = []
         self.shortcut = {
             "newFile": QKeySequence(QKeySequence.New).toString(),
@@ -112,15 +121,17 @@ class Settings():
             self.defaultEolMode = 1
         if os.getenv("SNAP"):
             self.useNativeIcons = False
-            self.searchUpdates = False
         else:
             self.useNativeIcons = True
-            self.searchUpdates = True
         if defaultSettings:
             for i in defaultSettings:
                 setattr(self,i[0],i[1])
 
     def loadDict(self, data: dict):
+        """
+        Loads Settings from a dict
+        :param data: The dict
+        """
         settings = vars(self)
         for key, value in data.items():
             settings[key] = value
@@ -130,13 +141,21 @@ class Settings():
             settings["editFont"] = font
 
     def load(self, path: str):
-        try:
-            with open(path,"r",encoding="utf-8") as f:
-                self.loadDict(json.load(f))
-        except:
+        """
+        Loads settings from a file
+        :param path: The path of the file
+        """
+        data = readJsonFile(path,None)
+        if data:
+            self.loadDict(data)
+        else:
             showMessageBox("Can't load settings","The settings can't be loaded. jdTextEdit will use the default settings.")
 
     def save(self, path: str):
+        """
+        Save all Settings to a file
+        :param path: The path of the file
+        """
         data = vars(self)
         font = self.editFont
         data["editFont"] = self.editFont.toString()
@@ -144,12 +163,28 @@ class Settings():
             json.dump(data, f, ensure_ascii=False, indent=4)
         self.editFont = font
 
-    def get(self, key: str):
+    def get(self, key: str) -> Any:
+        """
+        Returns the Value of a Setting
+        :param key: The Key
+        :return: The Value
+        """
         return vars(self)[key]
 
-    def set(self,key: str, value: str):
+    def set(self,key: str, value: Any):
+        """
+        Sets a setting
+        :param key: The Key
+        :param value: The new Value
+        :return:
+        """
         vars(self)[key] = value
 
-    def register(self,key: str,value: str):
+    def register(self,key: str,value: Any):
+        """
+        Register a new setting
+        :param key: The Key
+        :param value: The default Value
+        """
         if not hasattr(self,key):
             setattr(self,key,value)
