@@ -1,13 +1,13 @@
 from PyQt5.QtWidgets import QMenu
-from PyQt5.Qsci import QsciScintilla, QsciLexer, QsciAPIs, QsciScintillaBase
+from PyQt5.Qsci import QsciScintilla, QsciLexer, QsciScintillaBase, QsciMacro
 from PyQt5.QtGui import QColor, QFontMetrics, QFont, QCursor
 from PyQt5.QtCore import pyqtSignal
-from jdTextEdit.AutocompleteXML import AutocompleteXML
 from jdTextEdit.gui.BannerWidgets.EditorconfigBanner import EditorconfigBanner
 from jdTextEdit.api.LanguageBase import LanguageBase
 import editorconfig
 import traceback
 import copy
+import sys
 import os
 
 class CodeEdit(QsciScintilla):
@@ -84,30 +84,11 @@ class CodeEdit(QsciScintilla):
         elif self.eolMode() == QsciScintilla.EolMac:
             self.env.mainWindow.eolLabel.setText("CR")
 
-    def setSyntaxHighlighter(self, lexer, lexerList=None):
-        #self.lexer() is a little bit buggy
-        self.currentLexer = lexer
-        self.setLexer(lexer)
-        if lexerList:
-            if isinstance(lexerList["xmlapi"], str):
-                if os.path.isfile(os.path.join(self.env.programDir,"autocompletion",lexerList["xmlapi"] + ".xml")):
-                    self.apiCompletion = os.path.join(self.env.programDir,"autocompletion",lexerList["xmlapi"] + ".xml")
-                else:
-                    self.apiCompletion = None
-            else:
-                self.apiCompletion = lexerList["xmlapi"]
-        else:
-            self.apiCompletion = None
-        self.updateSettings(self.settings)
-        #self.setLexerColor(lexer,self.env.themes[self.settings.editTheme]["colors"])
-        if not self.isPreview:
-            self.lexerName = str(lexer.language())
-            self.updateStatusBar()
-            if not hasattr(self.env,"mainWindow"):
-                return
-            self.env.mainWindow.updateSelectedLanguage()
-
     def setLanguage(self,lang: LanguageBase):
+        """
+        Sets the Language.
+        :param lang: The Language
+        """
         lexer = lang.getLexer()
         self.currentLexer = lexer
         self.setLexer(lexer)
@@ -122,6 +103,9 @@ class CodeEdit(QsciScintilla):
         self.env.editorSignals.languageChanged.emit(self,lang)
 
     def removeLanguage(self):
+        """
+        Sets the Language to Plain Text
+        """
         self.setLexer(None)
         self.currentLexer = None
         self.language = None
@@ -130,7 +114,7 @@ class CodeEdit(QsciScintilla):
         self.updateStatusBar()
         self.env.editorSignals.languageChanged.emit(self,None)
 
-    def insertText(self, text):
+    def insertText(self, text: str):
         self.insert(text)
         line, pos = self.getCursorPosition()
         self.setCursorPosition(line,pos + len(text))
@@ -138,12 +122,12 @@ class CodeEdit(QsciScintilla):
     def modificationStateChange(self, state):
         if self.isPreview:
             return
-        #self.isNew = False
+        tabWidget = self.container.getTabWidget()
         try:
             if state:
-                self.env.mainWindow.tabWidget.setTabIcon(self.tabid,self.env.documentUnsavedIcon)
+                tabWidget.setTabIcon(self.tabid,self.env.documentUnsavedIcon)
             else:
-                self.env.mainWindow.tabWidget.setTabIcon(self.tabid,self.env.documentSavedIcon)
+                tabWidget.setTabIcon(self.tabid,self.env.documentSavedIcon)
         except:
             pass
 
@@ -293,20 +277,6 @@ class CodeEdit(QsciScintilla):
         if event.mimeData().text() != "" and len(event.mimeData().urls()) == 0:
             self.insertText(event.mimeData().text())
 
-    def setSingleLexerColor(self,lexer,color,name):
-        if isinstance(name,list):
-            for i in name:
-                try:
-                    lexer.setColor(QColor(color), getattr(lexer,i))
-                except:
-                    pass
-        else:
-            try:
-                lexer.setColor(QColor(color), getattr(lexer,name))
-            except:
-                print(lexer,name)
-                pass
-
     def getSaveMetaData(self):
         if self.language:
             syntax = self.language.getID()
@@ -329,7 +299,7 @@ class CodeEdit(QsciScintilla):
             "bookmarks": self.bookmarkList,
             "cursorPosLine": self.cursorPosLine,
             "cursorPosIndex": self.cursorPosIndex,
-            "zoom": self.SendScintilla(QsciScintillaBase.SCI_GETZOOM),
+            "zoom": self.getZoom(),
             "customSettings": self.custom_settings,
             "overwriteMode": self.overwriteMode(),
             "fileChangedBannerVisible": fileChangedBannerVisible,
@@ -360,7 +330,9 @@ class CodeEdit(QsciScintilla):
         self.setOverwriteMode(data.get("overwriteMode",False))
         modificationTime = data.get("modificationTime",0)
         if self.container:
-            if data.get( "fileChangedBannerVisible",False):
+            if not os.path.exists(path) and path != "":
+                self.container.showFileDeletedBanner()
+            elif data.get("fileChangedBannerVisible",False):
                 self.container.showFileChangedBanner()
             elif modificationTime != 0:
                 if modificationTime != os.path.getmtime(path):
@@ -368,6 +340,9 @@ class CodeEdit(QsciScintilla):
         self.env.editorSignals.restoreSession.emit(self,data)
 
     def loadEditorConfig(self):
+        """
+        Loads a .editorconfig file
+        """
         try:
             config = editorconfig.get_properties(self.getFilePath())
         except:
@@ -407,82 +382,6 @@ class CodeEdit(QsciScintilla):
         if self.container and self.settings.editorConfigShowBanner:
             self.container.showBanner(EditorconfigBanner(self.env,self.container))
 
-    def setLexerColor(self,lexer,style):
-        #return
-        lexer.setPaper(QColor(style.get("paperColor","#FFFFFF")))
-        lexer.setDefaultPaper(QColor(style.get("paperColor","#FFFFFF")))
-        lexer.setDefaultColor(QColor(style.get("textColor","#000000")))
-        #vars(lexer) just returns a empty dict
-        self.setSingleLexerColor(lexer,style.get("textColor","#000000"),[
-        "Default",
-        "JavaScriptDefault",
-        "JavaScriptWord"
-        ])
-        self.setSingleLexerColor(lexer,style.get("classNameColor","#0000ff"),"ClassName")
-        self.setSingleLexerColor(lexer,style.get("keywordColor","#00007f"),[
-        "Keyword",
-        "JavaScriptKeyword"
-        ])
-        self.setSingleLexerColor(lexer,style.get("commentColor","#007f00"),[
-            "Comment",
-            "LineComment",
-            "JavaScriptComment",
-            "JavaScriptCommentDoc",
-            "JavaScriptCommentLine",
-            "HTMLComment"
-        ])
-        self.setSingleLexerColor(lexer,style.get("numberColor","#007f7f"),[
-        "Number",
-        "JavaScriptNumber"
-        ])
-        self.setSingleLexerColor(lexer,style.get("stringColor","#7f007f"),[
-            "String",
-            "UnclosedString",
-            "DoubleQuotedString",
-            "TripleSingleQuotedString",
-            "TripleDoubleQuotedString",
-            "PHPSingleQuotedString",
-            "PHPDoubleQuotedString",
-            "HTMLSingleQuotedString",
-            "HTMLDoubleQuotedString",
-            "JavaScriptSingleQuotedString",
-            "JavaScriptDoubleQuotedString",
-            "JavaScriptUnclosedString"
-        ])
-        self.setSingleLexerColor(lexer,style.get("functionNameColor","#007f7f"),[
-            "BasicFunctions",
-            "FunctionMethodName"
-        ])
-        self.setSingleLexerColor(lexer,style.get("operatorColor","#000000"),"Operator")
-        self.setSingleLexerColor(lexer,style.get("identifierColor","#000000"),"Identifier")
-        self.setSingleLexerColor(lexer,style.get("tagColor","#cc0000"),"Tag")
-        '''
-        try:
-            lexer.setColor(QColor("#F1E607"), lexer.CommentBlock)
-        except:
-            pass
-        try:
-            lexer.setColor(QColor("#F1E607"), lexer.HighlightedIdentifier)
-        except:
-            pass
-        try:
-            lexer.setColor(QColor("#F1E607"), lexer.Decorator)
-        except:
-            pass
-        '''
-
-    def setCustomStyle(self,style):
-        #return
-        self.setColor(QColor(style.get("textColor","#000000")))
-        self.setPaper(QColor(style.get("paperColor","#FFFFFF")))
-        self.setSelectionForegroundColor(QColor(style.get("selectionForegroundColor","#FFFFFF")))
-        self.setSelectionBackgroundColor(QColor(style.get("selectionBackgroundColor","#308CC6")))
-        self.setMarginsBackgroundColor(QColor(style.get("marginsBackgroundColor","#cccccc")))
-        self.setMarginsForegroundColor(QColor(style.get("marginsForegroundColor","#000000")))
-        self.setCaretLineBackgroundColor(QColor(style.get("caretLineBackgroundColor","#ffff00")))
-        if self.currentLexer:
-           self.setLexerColor(self.currentLexer,style)
-
     def changeFont(self,font,settings):
         self.setFont(font)
         self.setMarginsFont(font)
@@ -503,11 +402,15 @@ class CodeEdit(QsciScintilla):
         self.env.editorSignals.settingsChanged.emit(self,settings)
 
     def updateSettings(self, settings):
-        #self.setCustomStyle(self.env.themes[settings.editTheme]["colors"])
-        try:
-            self.env.themes[settings.editTheme].applyTheme(self,self.currentLexer)
-        except Exception as e:
-            print(traceback.format_exc(),end="")
+        if settings.editTheme in self.env.themes:
+            try:
+                self.env.themes[settings.editTheme].applyTheme(self,self.currentLexer)
+            except Exception as e:
+                print(traceback.format_exc(),end="",file=sys.stderr)
+                self.env.themes["builtin.default"].applyTheme(self, self.currentLexer)
+        else:
+            print("The selected Theme could not be found. Falling back to the default Theme.",file=sys.stderr)
+            self.env.themes["builtin.default"].applyTheme(self,self.currentLexer)
         if settings.useCustomFont:
             self.changeFont(settings.editFont,settings)
         else:
@@ -557,3 +460,32 @@ class CodeEdit(QsciScintilla):
 
     def getLanguage(self):
         return self.language
+
+    def getZoom(self) -> int:
+        """
+        Returns the current zoom
+        :return: zoom
+        """
+        return self.SendScintilla(QsciScintillaBase.SCI_GETZOOM)
+
+    def updateOtherWidgets(self):
+        """
+        Updates the other widgets like MainWindow or the statusbar
+        :return:
+        """
+        self.updateEolMenu()
+        self.updateStatusBar()
+        self.updateMenuActions()
+        self.env.mainWindow.updateWindowTitle()
+        if self.env.mainWindow.currentMacro:
+            self.env.mainWindow.stopMacroRecording()
+            macro = self.env.mainWindow.currentMacro.save()
+            self.env.mainWindow.currentMacro = QsciMacro(self)
+            self.env.mainWindow.currentMacro.load(macro)
+
+    def focusInEvent(self, event):
+        if self.isPreview:
+            return
+        self.container.getTabWidget().markWidgetAsActive()
+        self.updateOtherWidgets()
+        super().focusInEvent(event)
\ No newline at end of file
