@@ -51,7 +51,9 @@ class StyleTab(QWidget,SettingsTabBase):
         self.lineNumberCheckBox.stateChanged.connect(self.updatePreviewEdit)
         self.highlightLineCheckBox.stateChanged.connect(self.updatePreviewEdit)
         self.editorPreview.setText(previewText)
-        self.editorPreview.setLexer(QsciLexerLua())
+        for i in self.env.languageList:
+            if i.getID() == "builtin.LUA":
+                self.editorPreview.setLanguage(i)
 
         gridLayout = QGridLayout()
         gridLayout.addWidget(QLabel(env.translate("settingsWindow.style.label.theme")),0,0)
@@ -92,7 +94,7 @@ class StyleTab(QWidget,SettingsTabBase):
     def updatePreviewEdit(self):
         self.editorPreview.setSettings(self.getSettings(Settings(defaultSettings=self.env.defaultSettings)))
 
-    def updateTab(self, settings):
+    def updateTab(self, settings: Settings):
         for i in range(self.themeSelect.count()):
             if self.themeSelect.itemData(i) == settings.editTheme:
                 self.themeSelect.setCurrentIndex(i)
@@ -110,7 +112,7 @@ class StyleTab(QWidget,SettingsTabBase):
         self.editorPreview.zoomTo(settings.defaultZoom)
         self.updatePreviewEdit()
 
-    def getSettings(self, settings):
+    def getSettings(self, settings: Settings):
         settings.editTheme = self.themeSelect.itemData(self.themeSelect.currentIndex())
         settings.editFoldStyle = self.foldSelect.currentIndex()
         settings.useCustomFont = bool(self.fontCheckBox.checkState())
@@ -120,5 +122,5 @@ class StyleTab(QWidget,SettingsTabBase):
         settings.defaultZoom = self.zoomSlider.value()
         return settings
 
-    def title(self):
+    def title(self) -> str:
         return self.env.translate("settingsWindow.style")
